@@ -7,7 +7,6 @@
 #include <qregexp.h>
 //Added by qt3to4:
 #include <QTextStream>
-#include <Q3CString>
 
 using namespace std;
 
@@ -43,7 +42,7 @@ static const char *cuttingtags[] = {"bridgehead", "trans_comment", "para", "titl
                                     "calloutlist", "callout", "subtitle",
 				    "table", "part", "xi:fallback", "primary",
                                     "secondary", "chapter", "sect1", "sect2",
-                                    "figure", "abstract", "sect3", "sect", "sect4",
+                                    "figure", "informalfigure", "abstract", "sect3", "sect", "sect4",
                                     "warning", "preface", "authorgroup", "keywordset",
 				    "informaltable", "qandaentry", "question", "answer",
 				    "othercredit", "affiliation", "qandaset",
@@ -57,13 +56,14 @@ static const char *cuttingtags[] = {"bridgehead", "trans_comment", "para", "titl
                                     "refsynopsisdiv", "refsysnopsisdivinfo", "remark",
                                     "revdescription", "glossentry", "partinfo",
 				    "segmentedlist", "segtitle", "seg", "seglistitem", "screenco",
+				    "titleabbrev", "date", "authorinitials", "holder", "releaseinfo",
                                     0};
 static const char *literaltags[] = {"literallayout", "synopsis", "screen",
 				    "programlisting", 0};
 
 bool StructureParser::fatalError ( const QXmlParseException &e )
 {
-    cerr << "fatalError " << e.message().latin1() << " " << e.lineNumber() << " "
+    cerr << "fatalError " << qPrintable(e.message()) << " " << e.lineNumber() << " "
          << e.columnNumber() << endl;
     return false;
 }
@@ -121,7 +121,7 @@ bool StructureParser::startElement( const QString& , const QString& ,
                                     const QString& qName,
                                     const QXmlAttributes & attr )
 {
-    QString tname = qName.lower();
+    QString tname = qName.toLower();
 
     bool first = false;
 
@@ -194,8 +194,8 @@ bool StructureParser::closureTag(const QString& message, const QString &tag)
     int index = 0;
     while (true)
     {
-        int nextclose = message.find(QRegExp(QString::fromLatin1("</%1[\\s>]").arg(tag)), index);
-        int nextstart = message.find(QRegExp(QString::fromLatin1("<%1[>\\s]").arg(tag)), index);
+        int nextclose = message.indexOf(QRegExp(QString::fromLatin1("</%1[\\s>]").arg(tag)), index);
+        int nextstart = message.indexOf(QRegExp(QString::fromLatin1("<%1[>\\s]").arg(tag)), index);
         //  qDebug("finding %d %d %d %d", nextstart, nextclose, index, inside);
         if (nextclose == -1) {
 #ifdef POXML_DEBUG
@@ -237,7 +237,7 @@ void StructureParser::descape(QString &message)
     bool lastws = false;
 
     while (index < message.length()) {
-        switch (message.at(index).latin1()) {
+        switch (message.at(index).toLatin1()) {
             case '\n':
             case '\t':
             case '\r':
@@ -284,7 +284,8 @@ bool StructureParser::formatMessage(MsgBlock &msg) const
     if (msg.msgid.isEmpty())
         return true;
 
-    for (int index = 0; msg.msgid.at(index) == ' '; index++, offset++);
+    for (int index = 0; msg.msgid.at(index) == ' '; index++, offset++)
+        ;
     stripWhiteSpace( msg.msgid );
 
     // removing starting single tags
@@ -304,12 +305,13 @@ bool StructureParser::formatMessage(MsgBlock &msg) const
             msg.msgid = msg.msgid.mid(strindex + 1);
             changed = true;
             offset += strindex + 1;
-            for (int index = 0; index < msg.msgid.length() && msg.msgid.at(index) == ' '; index++, offset++) ;
+            for (int index = 0; index < msg.msgid.length() && msg.msgid.at(index) == ' '; index++, offset++)
+                ;
             stripWhiteSpace( msg.msgid );
         }
     }
 
-    while (msg.msgid.right(2) == "/>")
+    while (msg.msgid.right(2) == "/>" && msg.msgid.startsWith('<'))
     {
         int strindex = msg.msgid.length() - 2;
         while (msg.msgid.at(strindex) != '<')
@@ -319,7 +321,8 @@ bool StructureParser::formatMessage(MsgBlock &msg) const
         changed = true;
     }
 
-    for (int index = 0; index < msg.msgid.length() && msg.msgid.at(index) == ' '; index++, offset++) ;
+    for (int index = 0; index < msg.msgid.length() && msg.msgid.at(index) == ' '; index++, offset++)
+        ;
     stripWhiteSpace( msg.msgid );
 
     while (true) {
@@ -341,7 +344,7 @@ bool StructureParser::formatMessage(MsgBlock &msg) const
         QString orig = msg.msgid;
 
         QString endtag = msg.msgid.mid(endindex + 2, msg.msgid.length() - (endindex + 2) - 1);
-        QString endtag_attr = endtag.mid(endtag.find(' '), endtag.length());
+        QString endtag_attr = endtag.mid(endtag.indexOf(' '), endtag.length());
         endtag.remove(infos_reg);
         if (endtag == starttag) {
             if (!closureTag(msg.msgid, starttag))
@@ -353,13 +356,20 @@ bool StructureParser::formatMessage(MsgBlock &msg) const
             while (msg.msgid.at(strindex) != '>')
                 strindex++;
             QString attr = msg.msgid.left(strindex);
+            QString real_attr = attr.mid(starttag.length() + 1);
+            const int real_attr_infos_reg_pos = infos_reg.indexIn(real_attr);
+            if (real_attr_infos_reg_pos >= 0) {
+                real_attr = real_attr.left(real_attr_infos_reg_pos);
+            }
             msg.msgid = msg.msgid.mid(strindex + 1);
+            msg.attrs = real_attr;
             offset += strindex + 1;
-            for (int index = 0; index < msg.msgid.length() && msg.msgid.at(index) == ' '; index++, offset++) ;
+            for (int index = 0; index < msg.msgid.length() && msg.msgid.at(index) == ' '; index++, offset++)
+                ;
             stripWhiteSpace( msg.msgid );
             msg.tag = starttag;
 
-            if (infos_reg.search(attr) >= 0) {
+            if (infos_reg.indexIn(attr) >= 0) {
                 msg.lines.first().start_line = infos_reg.cap(1).toInt();
                 msg.lines.first().start_col = infos_reg.cap(2).toInt();
 #ifdef POXML_DEBUG
@@ -367,12 +377,12 @@ bool StructureParser::formatMessage(MsgBlock &msg) const
 #endif
                 offset = 0;
 
-                if (infos_reg.search(endtag_attr) >= 0) {
+                if (infos_reg.indexIn(endtag_attr) >= 0) {
                     msg.lines.first().end_line = infos_reg.cap(1).toInt();
                     msg.lines.first().end_col = infos_reg.cap(2).toInt() + 1;
                 }
             }
-            if (do_not_split_reg.search(attr) >= 0) {
+            if (do_not_split_reg.indexIn(attr) >= 0) {
                 msg.do_not_split = true;
                 break;
             }
@@ -432,9 +442,9 @@ MsgList StructureParser::splitMessage(const MsgBlock &mb)
 #endif
 
                 // the exception for poxml_* attributes is made in the closing tag
-                int closing_index = message.find(QRegExp(QString::fromLatin1("</%1[\\s>]").arg(tag)),
+                int closing_index = message.indexOf(QRegExp(QString::fromLatin1("</%1[\\s>]").arg(tag)),
                                                  strindex);
-                int starting_index = message.find(QRegExp(QString::fromLatin1("<%1[\\s>]").arg(tag)),
+                int starting_index = message.indexOf(QRegExp(QString::fromLatin1("<%1[\\s>]").arg(tag)),
                                                   strindex);
 
 #ifdef POXML_DEBUG
@@ -524,8 +534,8 @@ MsgList StructureParser::splitMessage(const MsgBlock &mb)
         while (endindex >= 0 && (message.at(endindex) != '<' || message.at(endindex + 1) != '/'))
             endindex--;
         QString tag = message.mid(endindex + 2, message.length() - endindex - 3);
-        if (tag.find(' ') > 0 ) {
-            tag = tag.left(tag.find(' '));
+        if (tag.indexOf(' ') > 0 ) {
+            tag = tag.left(tag.indexOf(' '));
         }
 #ifdef POXML_DEBUG
         qDebug("behind tag %s", tag.latin1());
@@ -543,9 +553,9 @@ MsgList StructureParser::splitMessage(const MsgBlock &mb)
                 qDebug("inside %s %d", message.mid(strindex, 35).latin1(), inside);
 #endif
 
-                int closing_index = message.findRev(QRegExp(QString::fromLatin1("</%1[\\s>]").arg(tag)),
+                int closing_index = message.lastIndexOf(QRegExp(QString::fromLatin1("</%1[\\s>]").arg(tag)),
                                                     strindex - 1);
-                int starting_index = message.findRev(QRegExp(QString::fromLatin1("<%1[\\s>]").arg(tag)),
+                int starting_index = message.lastIndexOf(QRegExp(QString::fromLatin1("<%1[\\s>]").arg(tag)),
                                                      strindex - 1);
 
 #ifdef POXML_DEBUG
@@ -609,7 +619,7 @@ error:
 
 bool StructureParser::endElement( const QString& , const QString&, const QString& qName)
 {
-    QString tname = qName.lower();
+    QString tname = qName.toLower();
 
     // qDebug("endElement %s - %s %d", tname.latin1(), message.latin1(), inside);
 
@@ -649,7 +659,7 @@ bool StructureParser::endElement( const QString& , const QString&, const QString
                 // if the remaining text still starts with a tag, the poxml_ info
                 // is most probably more correct
                 if (!(*it).msgid.isEmpty() && (*it).msgid.at(0) == '<' && isClosure((*it).msgid)) {
-                    if (infos_reg.search((*it).msgid) >= 0) {
+                    if (infos_reg.indexIn((*it).msgid) >= 0) {
                         (*it).lines.first().start_line = infos_reg.cap(1).toInt();
                         (*it).lines.first().start_col =  infos_reg.cap(2).toInt();;
                         (*it).lines.first().offset = 0;
@@ -700,7 +710,7 @@ QString StructureParser::descapeLiterals( const QString &_contents) {
 
 void StructureParser::stripWhiteSpace( QString &contents)
 {
-    contents = contents.stripWhiteSpace();
+    contents = contents.trimmed();
     bool changed;
     do {
         changed = false;
@@ -732,13 +742,13 @@ void StructureParser::cleanupTags( QString &contents )
         QRegExp end(QString("</%1[\\s>]").arg(literaltags[index]));
         int strindex = 0;
         while (true) {
-            strindex = contents.find(start, strindex);
+            strindex = contents.indexOf(start, strindex);
             if (strindex < 0)
                 break;
             while (contents.at(strindex) != '>')
                 strindex++;
             strindex++; // one more
-            int endindex = contents.find(end, strindex);
+            int endindex = contents.indexOf(end, strindex);
             QString part = contents.mid(strindex, endindex - strindex);
             QString newpart = escapeLiterals(part);
             contents.replace(strindex, part.length(), newpart);
@@ -750,7 +760,7 @@ void StructureParser::cleanupTags( QString &contents )
     QRegExp unclosed("</(\\w*)\\s\\s*>");
     int index = -1;
     while (true) {
-        index = unclosed.search(contents, index + 1);
+        index = unclosed.indexIn(contents, index + 1);
         if (index < 0)
             break;
         QString tag = unclosed.cap(1);
@@ -762,7 +772,7 @@ void StructureParser::cleanupTags( QString &contents )
 
     index = -1;
     while (true) {
-        index = start.search(contents, index + 1);
+        index = start.indexIn(contents, index + 1);
         if (index < 0)
             break;
         QString tag = start.cap(1);
@@ -774,7 +784,7 @@ void StructureParser::cleanupTags( QString &contents )
 
     index = -1;
     while (true) {
-        index = singletag.search(contents, index + 1);
+        index = singletag.indexIn(contents, index + 1);
         if (index < 0)
             break;
         QString tag = singletag.cap(1);
@@ -786,7 +796,7 @@ void StructureParser::cleanupTags( QString &contents )
     QRegExp trans_comment("<!-- TRANS:([^<>]*)-->");
     index = -1;
     while (true) {
-        index = trans_comment.search(contents, index + 1);
+        index = trans_comment.indexIn(contents, index + 1);
         if (index < 0)
             break;
         QString msgid = trans_comment.cap(1);
@@ -806,10 +816,10 @@ static bool removeEmptyTag( QString &contents, const QString & tag)
     QRegExp empty(QString("<%1[^>]*>[\\s\n][\\s\n]*</%2\\s*>").arg(tag).arg(tag));
     int strindex = 0;
     while (true) {
-        strindex = contents.find(empty, strindex);
+        strindex = contents.indexOf(empty, strindex);
         if (strindex < 0)
             break;
-        qDebug("found empty tag %s", tag.latin1());
+        qDebug("found empty tag %s", qPrintable(tag));
         contents.replace(strindex, empty.matchedLength(), " ");
         strindex++;
         return true;
@@ -853,7 +863,7 @@ QString escape(QString message)
 
 void outputMsg(const char *prefix, const QString &message)
 {
-    QStringList list = QStringList::split('\n', message, true);
+    QStringList list = message.split('\n');
     QString line;
 
     if (list.count() == 1) {
@@ -861,20 +871,23 @@ void outputMsg(const char *prefix, const QString &message)
         if (line.isEmpty())
             cout << prefix << " \"\"\n";
         else
-            cout << prefix << " \"" << escape(line).utf8().data() << "\"\n";
+            cout << prefix << " \"" << escape(line).toUtf8().data() << "\"\n";
     } else {
         cout << prefix << " \"\"\n";
-        for (QStringList::ConstIterator it = list.begin(); it != list.end(); it++) {
+        QStringList::ConstIterator last = list.constEnd();
+        if (!list.isEmpty())
+            --last;
+        for (QStringList::ConstIterator it = list.constBegin(); it != list.constEnd(); it++) {
             line = *it;
             if (!line.isEmpty()) {
-                cout << "      \"" << escape(line).utf8().data();
-                if (it == list.fromLast())
+                cout << "      \"" << escape(line).toUtf8().data();
+                if (it == last)
                     cout << "\"\n";
                 else
                     cout << "\\n\"\n";
             } else {
                 cout << "      \"";
-                if (it != list.fromLast())
+                if (it != last)
                     cout << "\\n";
                 cout << "\"\n";
             }
@@ -886,7 +899,7 @@ QString escapePO(QString msgid)
 {
     int index = 0;
     while (true) {
-        index = msgid.find("\\n", index);
+        index = msgid.indexOf("\\n", index);
         if (index == -1)
             break;
         if (index >= 1 && msgid.at(index - 1) == '\\' && msgid.at(index - 2) != '\\') {
@@ -897,7 +910,7 @@ QString escapePO(QString msgid)
     }
     index = 0;
     while (true) {
-        index = msgid.find("\\\"", index);
+        index = msgid.indexOf("\\\"", index);
         if (index == -1)
             break;
         if (index > 1 && msgid.at(index - 1) == '\\' && msgid.at(index - 2) != '\\')
@@ -907,7 +920,7 @@ QString escapePO(QString msgid)
     }
     index = 0;
     while (true) {
-        index = msgid.find("\\t", index);
+        index = msgid.indexOf("\\t", index);
         if (index == -1)
             break;
         if (index > 0 && msgid.at(index - 1) == '\\')
@@ -917,7 +930,7 @@ QString escapePO(QString msgid)
     }
     index = 0;
     while (true) {
-        index = msgid.find("\\\\", index);
+        index = msgid.indexOf("\\\\", index);
         if (index == -1)
             break;
         msgid.replace(index, 2, "\\");
@@ -975,7 +988,7 @@ MsgList parseXML(const char *filename)
 
     // Remove all entity definitions now:
     while (true) {
-        int index = contents.find("<!ENTITY");
+        int index = contents.indexOf("<!ENTITY");
         if (index < 0)
             break;
         int inside = 0;
@@ -983,7 +996,7 @@ MsgList parseXML(const char *filename)
         QString replacement = "";
         while (contents.at(endindex) != '>' || inside)
         {
-            switch (contents.at(endindex).latin1()) {
+            switch (contents.at(endindex).toLatin1()) {
                 case '<':
                     inside++; break;
                 case '>':
@@ -1000,8 +1013,8 @@ MsgList parseXML(const char *filename)
         contents.replace(index, endindex - index, replacement);
     }
 
-    QTextStream ts(contents.utf8(), QIODevice::ReadOnly);
-    QXmlInputSource source( ts );
+    QTextStream ts(contents.toUtf8(), QIODevice::ReadOnly);
+    QXmlInputSource source( ts.device() );
     QXmlSimpleReader reader;
     reader.setFeature( "http://trolltech.com/xml/features/report-start-end-entity", true);
     reader.setContentHandler( &handler );
@@ -1028,7 +1041,7 @@ MsgList parseXML(const char *filename)
                 break;
             }
             if (found != msgids.end()) {
-                if (found.data() != (*it).tag) {
+                if (found.value() != (*it).tag) {
 #ifdef POXML_DEBUG
                     qDebug("same msgid for '%s' and '%s'", found.data().latin1(), (*it).tag.latin1());
 #endif
@@ -1038,7 +1051,7 @@ MsgList parseXML(const char *filename)
                          it2 != english.end(); it2++)
                     {
                         if ((*it2).msgid == msgid)
-                            (*it2).msgid = QString("<%1>").arg((*it2).tag) + msgid + QString("</%1>").arg((*it2).tag);
+                            (*it2).msgid = QString("<%1%2>").arg((*it2).tag).arg((*it2).attrs) + msgid + QString("</%1>").arg((*it2).tag);
                     }
                     break;
                 }
@@ -1048,6 +1061,29 @@ MsgList parseXML(const char *filename)
         }
     } while (changed);
 
+    // Remove any single word command block since
+    // it does not make sense to translate a command line command
+    {
+        MsgList::Iterator it = english.begin();
+        while (it != english.end())
+        {
+            if ((*it).tag == QLatin1String("command"))
+            {
+                bool hasSpaces = false;
+                for (int i = 0; !hasSpaces && i < (*it).msgid.length(); ++i)
+                    hasSpaces = (*it).msgid[i].isSpace();
+                if (!hasSpaces)
+                    it = english.erase(it);
+                else
+                    ++it;
+            }
+            else
+            {
+                ++it;
+            }
+        }
+    }
+
     return english;
 }
 
