@@ -30,6 +30,7 @@
 #include "umllistview.h"
 #include "umllistviewitem.h"
 #include "umlobjectlist.h"
+#include "umlscene.h"
 #include "umlview.h"
 #include "umlwidget.h"
 #include "uml.h"
@@ -77,17 +78,15 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
 
     if (fromView) {
         m_type = clip4;
-        UMLView *view = UMLApp::app()->currentView();
-        view->checkSelections();
-        if(!view->getSelectedWidgets(m_WidgetList)) {
-            return 0;
-        }
+        UMLScene *scene = UMLApp::app()->currentView()->umlScene();
+        scene->checkSelections();
+        m_WidgetList = scene->selectedWidgetsExt();
         //if there is no selected widget then there is no copy action
         if (!m_WidgetList.count()) {
             return 0;
         }
-        m_AssociationList = view->getSelectedAssocs();
-        view->copyAsImage(png);
+        m_AssociationList = scene->selectedAssocs();
+        scene->copyAsImage(png);
 
     } else { //if the copy action is being performed from the ListView
         UMLListViewItemList itemsSelected = listView->selectedItems();
@@ -108,7 +107,7 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
             //For each selected view select all the Actors, USe Cases and Concepts
             //widgets in the ListView
             foreach (UMLView* view, m_ViewList ) {
-                UMLObjectList objects = view->umlObjects();
+                UMLObjectList objects = view->umlScene()->umlObjects();
                 foreach (UMLObject* o, objects ) {
                     UMLListViewItem *item = listView->findUMLObject(o);
                     if (item) {
@@ -140,7 +139,7 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
         if (png) {
             UMLView *view = UMLApp::app()->currentView();
             data = new UMLDragData(m_ObjectList, m_WidgetList,
-                               m_AssociationList, *png, view->type());
+                                   m_AssociationList, *png, view->umlScene()->type());
         } else {
             return 0;
         }
@@ -298,7 +297,7 @@ void UMLClipboard::checkItemForCopyType(UMLListViewItem* item, bool & withDiagra
     } else if ( Model_Utils::typeIsDiagram(type) ) {
         withDiagrams = true;
         onlyAttsOps = false;
-        view = doc->findView( item->getID() );
+        view = doc->findView( item->ID() );
         m_ViewList.append( view );
     } else if ( Model_Utils::typeIsFolder(type) ) {
         onlyAttsOps = false;
@@ -354,7 +353,7 @@ bool UMLClipboard::pasteChildren(UMLListViewItem *parent, IDChangeLog *chgLog)
     UMLListView *listView = UMLApp::app()->listView();
     for (int i = 0; i < parent->childCount(); i++) {
         UMLListViewItem *childItem = static_cast<UMLListViewItem*>(parent->child(i));
-        Uml::IDType oldID = childItem->getID();
+        Uml::IDType oldID = childItem->ID();
         Uml::IDType newID = chgLog->findNewID(oldID);
         UMLListViewItem *shouldNotExist = listView->findItem(newID);
         if (shouldNotExist) {
@@ -537,7 +536,8 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
         return false;
     }
 
-    if( diagramType != UMLApp::app()->currentView()->type() ) {
+    UMLScene *currentScene = UMLApp::app()->currentView()->umlScene();
+    if( diagramType != currentScene->type() ) {
         if( !checkPasteWidgets(widgets) ) {
             while ( !assocs.isEmpty() ) {
                 delete assocs.takeFirst();
@@ -561,25 +561,26 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
 
     //now add any widget we are want to paste
     bool objectAlreadyExists = false;
-    UMLView *currentView = UMLApp::app()->currentView();
-    currentView->beginPartialWidgetPaste();
+    currentScene->beginPartialWidgetPaste();
 
     foreach ( UMLWidget* widget, widgets ) {
 
         Uml::IDType oldId = widget->id();
         Uml::IDType newId = idchanges->findNewID(oldId);
         // how should findWidget find ::None id, which is returned for the first entry ?
-        if (currentView->findWidget(newId)) {
+        if (currentScene->findWidget(newId)) {
             uError() << "widget (oldID=" << ID2STR(oldId) << ", newID="
                 << ID2STR(newId) << ") already exists in target view.";
             widgets.removeAll(widget);
             delete widget;
             objectAlreadyExists = true;
         } else {
-            if (currentView->type() == Uml::DiagramType::Activity || currentView->type() == Uml::DiagramType::State)
+            if (currentScene->type() == Uml::DiagramType::Activity ||
+                currentScene->type() == Uml::DiagramType::State) {
                 widget->setID(doc->assignNewID(widget->id()));
-            if (! currentView->addWidget(widget, true)) {
-                currentView->endPartialWidgetPaste();
+            }
+            if (! currentScene->addWidget(widget, true)) {
+                currentScene->endPartialWidgetPaste();
                 return false;
             }
         }
@@ -587,21 +588,21 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
 
     //now paste the associations
     foreach ( AssociationWidget* assoc, assocs ) {
-        if (!currentView->addAssociation(assoc, true)) {
-            currentView->endPartialWidgetPaste();
+        if (!currentScene->addAssociation(assoc, true)) {
+            currentScene->endPartialWidgetPaste();
             return false;
         }
     }
 
-    currentView->clearSelected();
-    currentView->selectWidgets(widgets);
+    currentScene->clearSelected();
+    currentScene->selectWidgets(widgets);
     foreach ( AssociationWidget* assoc, assocs ) {
-        currentView->selectWidgetsOfAssoc(assoc);
+        currentScene->selectWidgetsOfAssoc(assoc);
     }
 
     //Activate all the pasted associations and widgets
-    currentView->activate();
-    currentView->endPartialWidgetPaste();
+    currentScene->activate();
+    currentScene->endPartialWidgetPaste();
 
     /*
     UMLListView *listView = UMLApp::app()->listView();
