@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2007 Jari-Matti Mäkelä <jmjm@iki.fi>                    *
- *   copyright (C) 2008-2010                                               *
+ *   copyright (C) 2008-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -16,7 +16,6 @@
 #include <QtCore/QRegExp>
 
 #include <kconfig.h>
-#include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
@@ -25,22 +24,14 @@
 #include "dcodecomment.h"
 #include "uml.h"
 
-/**
- * Constructor.
- * @param elem   DOM element
- */
-DCodeGenerator::DCodeGenerator(QDomElement & elem)
-  : CodeGenerator(elem)
-{
-    init();
-}
-
 /**
  * Constructor.
  */
 DCodeGenerator::DCodeGenerator()
+  : CodeGenerator()
 {
-    init();
+    // load Classifier documents from parent document
+    //initFromParentDocument();
 }
 
 /**
@@ -54,9 +45,9 @@ DCodeGenerator::~DCodeGenerator()
  * Return our language.
  * @return language identifier
  */
-Uml::Programming_Language DCodeGenerator::language() const
+Uml::ProgrammingLanguage DCodeGenerator::language() const
 {
-    return Uml::pl_D;
+    return Uml::ProgrammingLanguage::D;
 }
 
 /**
@@ -76,7 +67,7 @@ CodeViewerDialog * DCodeGenerator::getCodeViewerDialog ( QWidget* parent, CodeDo
  */
 DCodeGenerationPolicy * DCodeGenerator::getDPolicy()
 {
-    return dynamic_cast<DCodeGenerationPolicy*>(UMLApp::app()->getPolicyExt());
+    return dynamic_cast<DCodeGenerationPolicy*>(UMLApp::app()->policyExt());
 }
 
 /**
@@ -147,15 +138,6 @@ CodeDocument * DCodeGenerator::newClassifierCodeDocument ( UMLClassifier * class
     return doc;
 }
 
-/**
- * Initialization of class.
- */
-void DCodeGenerator::init()
-{
-    // load Classifier documents from parent document
-    //initFromParentDocument();
-}
-
 /**
  * Adds D's primitives as datatypes.
  * @return the list of primitive datatypes
