@@ -17,7 +17,7 @@
 #include "model_utils.h"
 #include "uml.h"
 #include "umldoc.h"
-#include "umlview.h"
+#include "umlscene.h"
 #include "umlviewlist.h"
 
 // kde includes
@@ -81,10 +81,10 @@ DiagramPrintPage::DiagramPrintPage(QWidget * parent, UMLDoc * doc)
     select->addWidget(m_pSelectLW);
     m_pSelectLW->setEnabled(false);
     m_pSelectLW->setSelectionMode(QAbstractItemView::MultiSelection);
-    m_pSelectLW->addItem(UMLApp::app()->currentView()->name());
+    m_pSelectLW->addItem(UMLApp::app()->currentView()->umlScene()->name());
     m_pSelectLW->setCurrentRow(0);
     m_nIdList.clear();
-    m_nIdList.append(UMLApp::app()->currentView()->getID());
+    m_nIdList.append(UMLApp::app()->currentView()->umlScene()->ID());
 
     m_ViewType = Uml::DiagramType(Uml::DiagramType::Class);
     connect(m_pAllRB, SIGNAL(clicked()), this, SLOT(slotClicked()));
@@ -135,7 +135,7 @@ QString DiagramPrintPage::printUmlDiagram(int sel)
         if (isSelected(i)) {
             if (count == sel) {
                 UMLView *view = (UMLView *)m_doc->findView(m_nIdList[i]);
-                QString sID = QString("%1").arg(ID2STR(view->getID()));
+                QString sID = QString("%1").arg(ID2STR(view->umlScene()->ID()));
                 return sID;
             }
             count++;
@@ -191,13 +191,14 @@ void DiagramPrintPage::slotClicked()
     // clear list with diagrams to print
     m_nIdList.clear();
 
+    UMLScene *currentScene = UMLApp::app()->currentView()->umlScene();
     if (m_pCurrentRB->isChecked()) {
         m_pTypeCB->setEnabled(false);
         m_pSelectLW->setEnabled(false);
         m_pSelectLW->clear();
-        m_pSelectLW->addItem(UMLApp::app()->currentView()->name());
+        m_pSelectLW->addItem(currentScene->name());
         m_pSelectLW->setCurrentRow(0);
-        m_nIdList.append(UMLApp::app()->currentView()->getID());
+        m_nIdList.append(currentScene->ID());
     }
 
     if (m_pAllRB->isChecked()) {
@@ -205,8 +206,8 @@ void DiagramPrintPage::slotClicked()
         m_pSelectLW->setEnabled(false);
         m_pSelectLW->clear();
         foreach ( UMLView * view , list ) {
-            m_pSelectLW->addItem(view->name());
-            m_nIdList.append(view->getID());
+            m_pSelectLW->addItem(view->umlScene()->name());
+            m_nIdList.append(view->umlScene()->ID());
         }
         m_pSelectLW->selectAll();
     }
@@ -216,8 +217,8 @@ void DiagramPrintPage::slotClicked()
         m_pSelectLW->setEnabled(true);
         m_pSelectLW->clear();
         foreach ( UMLView * view , list) {
-            m_pSelectLW->addItem(view->name());
-            m_nIdList.append(view->getID());
+            m_pSelectLW->addItem(view->umlScene()->name());
+            m_nIdList.append(view->umlScene()->ID());
         }
     }
 
@@ -226,9 +227,9 @@ void DiagramPrintPage::slotClicked()
         m_pSelectLW->setEnabled(true);
         m_pSelectLW->clear();
         foreach ( UMLView * view , list) {
-            if(view->type() == m_ViewType) {
-                m_pSelectLW->addItem(view->name());
-                m_nIdList.append(view->getID());
+            if(view->umlScene()->type() == m_ViewType) {
+                m_pSelectLW->addItem(view->umlScene()->name());
+                m_nIdList.append(view->umlScene()->ID());
             }
         }
         m_pSelectLW->selectAll();
@@ -252,9 +253,9 @@ void DiagramPrintPage::slotActivated(int index)
 
     m_nIdList.clear();
     foreach (UMLView * view , list) {
-        if (view->type() == m_ViewType) {
-            m_pSelectLW->addItem(view->name());
-            m_nIdList.append(view->getID());
+        if (view->umlScene()->type() == m_ViewType) {
+            m_pSelectLW->addItem(view->umlScene()->name());
+            m_nIdList.append(view->umlScene()->ID());
         }
     }
     m_pSelectLW->selectAll();
