@@ -301,6 +301,24 @@ UMLObject* findUMLObjectRaw(const UMLObjectList& inList,
     return NULL;
 }
 
+/**
+ * Get the root folder of the given UMLObject.
+ */
+UMLPackage* rootPackage(UMLObject* obj)
+{
+    if (obj == NULL)
+        return NULL;
+    UMLPackage* root = obj->umlPackage();
+    if (root == NULL) {
+        root = dynamic_cast<UMLPackage*>(obj);
+    } else {
+        while (root->umlPackage() != NULL) {
+            root = root->umlPackage();
+        }
+    }
+    return root;
+}
+
 /**
  * Add the given list of views to the tree view.
  * @param viewList   the list of views to add
@@ -309,7 +327,7 @@ void treeViewAddViews(const UMLViewList& viewList)
 {
     UMLListView* tree = UMLApp::app()->listView();
     foreach (UMLView* v,  viewList) {
-        if (tree->findItem(v->umlScene()->getID()) != NULL) {
+        if (tree->findItem(v->umlScene()->ID()) != NULL) {
             continue;
         }
         tree->createDiagramItem(v);
